# where

Python package: https://pypi.org/project/photos-where/ 

Use:

```
$ where-when Dropbox/Photos/2020/
$ ls where
cities-pie.jpg      
countries-pie.jpg
intervals.csv
location-by-day.csv 
photos.feather     
years.jpg
```

## Jupyter examples:

See ``example.ipynb`` for example graphs and data frames exported.